@@ -20,6 +20,7 @@
  */
 
 #include "filemetadatadatedisplaytest.h"
+#include <filemetadatawidget.h>
 
 
 #include <QObject>
@@ -32,9 +33,15 @@
 #include <QDateTime>
 #include <QScopedPointer>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+#include <time.h>
+#include <utime.h>
+#include <sys/stat.h>
+#endif
+
 void initLocale()
 {
-    QLocale::setDefault(QLocale(QLocale::English, QLocale::UnitedStates));
+    QLocale::setDefault(QLocale("en_US"));
 }
 Q_CONSTRUCTOR_FUNCTION(initLocale)
 
@@ -43,10 +50,21 @@ QTEST_MAIN(FileMetadataDateDisplayTest)
 bool FileMetadataDateDisplayTest::setFileTime(const QString& filePath, const QDateTime& fileTime)
 {
     bool ret;
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+    struct stat fileStat;
+    struct utimbuf newTimes;
+    const QByteArray file = QFile::encodeName(filePath);
+    stat(file, &fileStat);
+
+    newTimes.actime = fileStat.st_atime;
+    newTimes.modtime = fileTime.toTime_t();
+    ret = (utime(file, &newTimes) == 0);
+#else
     QScopedPointer<QFile> file{new QFile(filePath)};
     file->open(QIODevice::ReadOnly);
     ret = file->setFileTime(fileTime, QFileDevice::FileModificationTime);
     file->close();
+#endif
     return ret;
 }
 
@@ -76,25 +94,25 @@ void FileMetadataDateDisplayTest::shouldDisplayLongAndShortDates_data()
     QTest::addRow("Short date, long ago")
         << Baloo::DateFormats::ShortFormat
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.mp3"))
-        << QRegularExpression(QStringLiteral("(?:[1-3][0-9]|[1-9]) (?:[1-2][0-9]|[1-9]):[0-5][0-9] [AP]M"))
+        << QRegularExpression("(?:[1-3][0-9]|[1-9]) (?:[1-2][0-9]|[1-9]):[0-5][0-9] [AP]M")
     ;
 
     QTest::addRow("Short date, yesterday")
         << Baloo::DateFormats::ShortFormat
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.m4a"))
-        << QRegularExpression(QStringLiteral("Yesterday, (?:[1-2][0-9]|[1-9]):[0-5][0-9] [AP]M"))
+        << QRegularExpression("Yesterday, (?:[1-2][0-9]|[1-9]):[0-5][0-9] [AP]M")
     ;
 
     QTest::addRow("Long date, long ago")
         << Baloo::DateFormats::LongFormat
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.mp3"))
-        << QRegularExpression(QStringLiteral("[A-Z][a-z]+, [A-Z][a-z]+ (?:[1-3][0-9]|[1-9]), 20[0-9]{2} (?:1[0-2]|[1-9]):[0-5][0-9]:[0-5][0-9] [AP]M [A-Z]{3,4}"))
+        << QRegularExpression("[A-Z][a-z]+, [A-Z][a-z]+ (?:[1-3][0-9]|[1-9]), 20[0-9]{2} (?:1[0-2]|[1-9]):[0-5][0-9]:[0-5][0-9] [AP]M [A-Z]{3,4}")
     ;
 
     QTest::addRow("Long date, yesterday")
         << Baloo::DateFormats::LongFormat
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.m4a"))
-        << QRegularExpression(QStringLiteral("Yesterday, (?:1[0-2]|[1-9]):[0-5][0-9]:[0-5][0-9] [AP]M [A-Z]{3,4}"))
+        << QRegularExpression("Yesterday, (?:1[0-2]|[1-9]):[0-5][0-9]:[0-5][0-9] [AP]M [A-Z]{3,4}")
     ;
 
 }
