@@ -37,16 +37,14 @@ public:
     void start() override;
 
     QVariantMap data() const;
-    bool canEdit() const;
 
 private Q_SLOTS:
-    void slotIndexedFile(int exitCode, QProcess::ExitStatus exitStatus);
+    void slotIndexedFile(int error);
 
 private:
     QString m_url;
     QProcess* m_process;
     QVariantMap m_data;
-    bool m_canEdit = false;
 };
 
 }
